@@ -3,13 +3,13 @@ OCR-D reference implementation, base package: decorators and classes for process
 
 Related (and dependent) packages:
 
-* ``ocrd_utils``
+* :py:mod:`ocrd_utils`
   Contains utilities and constants, e.g. for logging, path normalization, coordinate calculation etc.
-* ``ocrd_models``
+* :py:mod:`ocrd_models`
   Contains file format wrappers for PAGE-XML, METS, EXIF metadata etc.
-* ``ocrd_modelfactory``
+* :py:mod:`ocrd_modelfactory`
   Code to instantiate models from existing data.
-* ``ocrd_validators``
+* :py:mod:`ocrd_validators`
   Schemas and routines for validating BagIt, ``ocrd-tool.json``, workspaces, METS, page, CLI parameters etc.
 
 """
@@ -20,3 +20,4 @@ from ocrd.resolver import Resolver
 from ocrd_validators import *
 from ocrd.workspace import Workspace
 from ocrd.workspace_backup import WorkspaceBackupManager
+from ocrd.resource_manager import OcrdResourceManager
