@@ -1,12 +1,14 @@
 from datetime import datetime
 from os import makedirs, chdir, walk
 from os.path import join, isdir, basename, exists, relpath
+from pathlib import Path
 from shutil import make_archive, rmtree, copyfile, move
-from tempfile import mkdtemp
+from tempfile import mkdtemp, TemporaryDirectory
 import re
 import tempfile
 import sys
-from bagit import Bag, make_manifests, _load_tag_file  # pylint: disable=no-name-in-module
+from bagit import Bag, make_manifests, _load_tag_file, _make_tag_file, _make_tagmanifest_file  # pylint: disable=no-name-in-module
+from distutils.dir_util import copy_tree
 
 from ocrd_utils import (
     pushd_popd,
@@ -37,12 +39,7 @@ class WorkspaceBagger():
         self.resolver = resolver
         self.strict = strict
 
-    def _serialize_bag(self, workspace, bagdir, dest, in_place, skip_zip):
-        if in_place:
-            if not exists(BACKUPDIR):
-                makedirs(BACKUPDIR)
-            backupdir = mkdtemp(dir=BACKUPDIR)
-            move(workspace.directory, backupdir)
+    def _serialize_bag(self, workspace, bagdir, dest, skip_zip):
         if skip_zip:
             move(bagdir, dest)
         else:
@@ -139,7 +136,6 @@ class WorkspaceBagger():
             ocrd_base_version_checksum=None,
             processes=1,
             skip_zip=False,
-            in_place=False,
             tag_files=None
            ):
         """
@@ -155,14 +151,8 @@ class WorkspaceBagger():
             ord_base_version_checksum (string): Ocrd-Base-Version-Checksum in bag-info.txt
             processes (integer): Number of parallel processes checksumming
             skip_zip (boolean): Whether to leave directory unzipped
-            in_place (boolean): Whether to **replace** the workspace with its BagIt variant
             tag_files (list<string>): Path names of additional tag files to be bagged at the root of the bag
         """
-        if in_place and (dest is not None):
-            raise Exception("Setting 'dest' and 'in_place' is a contradiction")
-        if in_place and not skip_zip:
-            raise Exception("Setting 'skip_zip' and not 'in_place' is a contradiction")
-
         if tag_files is None:
             tag_files = []
 
@@ -170,15 +160,13 @@ class WorkspaceBagger():
         bagdir = mkdtemp(prefix=TMP_BAGIT_PREFIX)
 
         if dest is None:
-            if in_place:
-                dest = workspace.directory
-            elif not skip_zip:
+            if not skip_zip:
                 dest = '%s.ocrd.zip' % workspace.directory
             else:
                 dest = '%s.ocrd' % workspace.directory
 
         log = getLogger('ocrd.workspace_bagger')
-        log.info("Bagging %s to %s (temp dir %s)", workspace.directory, '(in-place)' if in_place else dest, bagdir)
+        log.info("Bagging %s to %s (temp dir %s)", workspace.directory, dest, bagdir)
 
         # create data dir
         makedirs(join(bagdir, 'data'))
@@ -201,7 +189,7 @@ class WorkspaceBagger():
         bag.save()
 
         # ZIP it
-        self._serialize_bag(workspace, bagdir, dest, in_place, skip_zip)
+        self._serialize_bag(workspace, bagdir, dest, skip_zip)
 
         log.info('Created bag at %s', dest)
         return dest
@@ -270,3 +258,56 @@ class WorkspaceBagger():
             - https://ocr-d.github.io/bagit-profile.json
             - https://ocr-d.github.io/bagit-profile.yml
         """
+        pass
+
+    def recreate_checksums(self, src, dest=None, overwrite=False):
+        """
+        (Re)creates the files containing the checksums of a bag
+
+        This function uses bag.py to create new files: manifest-sha512.txt and
+        tagminifest-sha512.txt for the bag. Also 'Payload-Oxum' in bag-info.txt will be set to the
+        appropriate value.
+
+        Arguments:
+            src (string):    Path to Bag. May be an zipped or unziped bagit
+            dest (string):   Path to where the result should be stored. Not needed if overwrite is
+                             set
+            overwrite(bool): Replace bag with newly created bag
+        """
+        if overwrite and dest:
+            raise Exception("Setting 'dest' and 'overwrite' is a contradiction")
+        if not overwrite and not dest:
+            raise Exception("For checksum recreation 'dest' must be provided")
+        src_path = Path(src)
+        if not src_path.exists():
+            raise Exception("Path to bag not existing")
+        is_zipped = src_path.is_file()
+
+        with TemporaryDirectory() as tempdir:
+            if is_zipped:
+                unzip_file_to_dir(src, tempdir)
+                path_to_bag = Path(tempdir)
+                if not path_to_bag.joinpath("data").exists():
+                    raise FileNotFoundError("data directory of bag not found")
+            else:
+                path_to_bag = src_path if overwrite else Path(dest)
+                if not src_path.joinpath("data").exists():
+                    raise FileNotFoundError(f"data directory of bag not found at {src}")
+                if not overwrite:
+                    path_to_bag.mkdir(parents=True, exist_ok=True)
+                    copy_tree(src, dest)
+
+            with pushd_popd(path_to_bag):
+                n_bytes, n_files = make_manifests("data", 1, ["sha512"])
+
+                bag_infos = _load_tag_file("bag-info.txt")
+                bag_infos["Payload-Oxum"] = f"{n_bytes}.{n_files}"
+                _make_tag_file("bag-info.txt", bag_infos)
+                _make_tagmanifest_file("sha512", ".")
+
+            if is_zipped:
+                name = src_path.name
+                if name.endswith(".zip"):
+                    name = name[:-4]
+                zip_path = make_archive(name, "zip", path_to_bag)
+                move(zip_path, src if overwrite else dest)
